@@ -15,7 +15,7 @@ def w_for_global_constr(obj, layout_11, layout_12, layout_13, layout_2, layout_3
 
     
     layout_11.addWidget(QtWidgets.QLabel("Defined attributes:"))
-    _widg_table = make_qtablewidget_for_data_constr(obj, w_output)
+    _widg_table = make_qtablewidget_for_data_constr(obj, w_output, thread)
     layout_11.addWidget(_widg_table)
 
 
@@ -23,7 +23,7 @@ def w_for_global_constr(obj, layout_11, layout_12, layout_13, layout_2, layout_3
     _b_info.clicked.connect(lambda : show_info(obj, w_output))
     layout_11.addWidget(_b_info)
 
-    layout_12.addLayout(add_mandatory_optional_obj(obj, w_output))
+    layout_12.addLayout(add_mandatory_optional_obj(obj, w_output, thread))
 
     layout_13.addLayout(get_layout_method_help(obj, w_output, thread))
 
